==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/WORKORDERQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WORKORDERQUALIFICATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WORKORDERQUALIFICATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONSOURCEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WORKORDERQUALIFICATIONID_Type", propOrder = {
    "activityid",
    "qualificationid",
    "qualificationsourceid",
    "jobsequence"
})
public class WORKORDERQUALIFICATIONID_Type {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "QUALIFICATIONSOURCEID", required = true)
    protected QUALIFICATIONSOURCEID_Type qualificationsourceid;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété qualificationid.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Définit la valeur de la propriété qualificationid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Obtient la valeur de la propriété qualificationsourceid.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONSOURCEID_Type }
     *     
     */
    public QUALIFICATIONSOURCEID_Type getQUALIFICATIONSOURCEID() {
        return qualificationsourceid;
    }

    /**
     * Définit la valeur de la propriété qualificationsourceid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONSOURCEID_Type }
     *     
     */
    public void setQUALIFICATIONSOURCEID(QUALIFICATIONSOURCEID_Type value) {
        this.qualificationsourceid = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/WORKORDERQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WORKORDERQUALIFICATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WORKORDERQUALIFICATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONSOURCEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WORKORDERQUALIFICATIONID_Type", propOrder = {
    "activityid",
    "qualificationid",
    "qualificationsourceid",
    "jobsequence"
})
public class WORKORDERQUALIFICATIONID_Type {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "QUALIFICATIONSOURCEID", required = true)
    protected QUALIFICATIONSOURCEID_Type qualificationsourceid;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Sets the value of the qualificationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Gets the value of the qualificationsourceid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONSOURCEID_Type }
     *     
     */
    public QUALIFICATIONSOURCEID_Type getQUALIFICATIONSOURCEID() {
        return qualificationsourceid;
    }

    /**
     * Sets the value of the qualificationsourceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONSOURCEID_Type }
     *     
     */
    public void setQUALIFICATIONSOURCEID(QUALIFICATIONSOURCEID_Type value) {
        this.qualificationsourceid = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}
